@@ -19,6 +19,7 @@ import sys
 from .variables import dimensions, \
     horizontal_coordinates_spherical, horizontal_coordinates_cartesian, \
     horizontal_coordinates_curvcart, horizontal_coordinates_llc, \
+    horizontal_coordinates_cs, \
     vertical_coordinates, horizontal_grid_variables, vertical_grid_variables, \
     volume_grid_variables, state_variables, aliases, package_state_variables, \
     extra_grid_variables, mask_variables
@@ -45,7 +46,8 @@ except ImportError:
 
 # should we hard code this?
 LLC_NUM_FACES = 13
-LLC_FACE_DIMNAME = 'face'
+CS_NUM_FACES = 6
+FACE_DIMNAME = 'face'
 
 
 def open_mdsdataset(data_dir, grid_dir=None,
@@ -84,7 +86,7 @@ def open_mdsdataset(data_dir, grid_dir=None,
     levels : list or slice, optional
         A list or slice of the indexes of the grid levels to read
         Same syntax as in the data.diagnostics file
-    geometry : {'sphericalpolar', 'cartesian', 'llc', 'curvilinear'}
+    geometry : {'sphericalpolar', 'cartesian', 'llc', 'curvilinear', 'cs'}
         MITgcm grid geometry specifier
     grid_vars_to_coords : boolean, optional
         Whether to promote grid variables to coordinate status
@@ -151,7 +153,8 @@ def open_mdsdataset(data_dir, grid_dir=None,
         if read_grid == False:
             swap_dims = False
         else:
-            swap_dims = False if geometry in ('llc', 'curvilinear') else True
+            swap_dims = False if geometry in (
+                'llc', 'cs', 'curvilinear') else True
 
     # some checks for argument consistency
     if swap_dims and not read_grid:
@@ -254,7 +257,6 @@ def open_mdsdataset(data_dir, grid_dir=None,
                           nx=nx, ny=ny, nz=nz, llc_method=llc_method,
                           levels=levels, extra_metadata=extra_metadata)
     ds = xr.Dataset.load_store(store)
-
     if swap_dims:
         ds = _swap_dimensions(ds, geometry)
     if grid_vars_to_coords:
@@ -289,15 +291,15 @@ def _set_coords(ds):
 
 
 def _swap_dimensions(ds, geometry, drop_old=True):
-    """Replace logical coordinates with physical ones. Does not work for llc.
+    """Replace logical coordinates with physical ones. Does not work for llc or cs.
     """
     keep_attrs = ['axis', 'c_grid_axis_shift']
 
     # this fixes problems
     ds = ds.reset_coords()
 
-    if geometry.lower() in ('llc', 'curvilinear'):
-        raise ValueError("Can't swap dimensions if `geometry` is `llc`")
+    if geometry.lower() in ('llc', 'cs', 'curvilinear'):
+        raise ValueError("Can't swap dimensions if `geometry` is `llc` or `cs`")
 
     # first squeeze all the coordinates
     for orig_dim in ds.dims:
@@ -350,7 +352,8 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
         """
 
         self.geometry = geometry.lower()
-        allowed_geometries = ['cartesian', 'sphericalpolar', 'llc', 'curvilinear']
+        allowed_geometries = ['cartesian',
+                              'sphericalpolar', 'llc', 'cs', 'curvilinear']
         if self.geometry not in allowed_geometries:
             raise ValueError('Unexpected value for parameter `geometry`. '
                              'It must be one of the following: %s' %
@@ -379,6 +382,7 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
         # the dimensions are theoretically the same for all datasets
         [self._dimensions.append(k) for k in dimensions]
         self.llc = (self.geometry == 'llc')
+        self.cs = (self.geometry == 'cs')
 
         if nz is None:
             self.nz = _guess_model_nz(self.grid_dir)
@@ -402,6 +406,13 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
                 # and we cannot know nx at this point
                 llc = get_extra_metadata(domain='llc', nx=90)
                 extra_metadata = llc
+        if self.cs:
+            has_faces = True
+            if extra_metadata is None or 'ny_facets' not in extra_metadata:
+                # default to llc90, we only need number of facets
+                # and we cannot know nx at this point
+                cs = get_extra_metadata(domain='cs', nx=32)
+                extra_metadata = cs
         # --------------- /LEGACY ----------------------
 
         # we don't need to know ny if using llc
@@ -419,7 +430,7 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
         else:
             # have to peek at the grid file metadata
             self.nface, self.ny, self.nx = (
-                _guess_model_horiz_dims(self.grid_dir, self.llc))
+                _guess_model_horiz_dims(self.grid_dir, is_llc=self.llc, is_cs=self.cs))
 
         # --------------- LEGACY ----------------------
         if self.llc:
@@ -427,6 +438,11 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
                 # if user didn't provide metadata, we default to llc
                 llc = get_extra_metadata(domain='llc', nx=self.nx)
                 extra_metadata = llc
+        if self.cs:
+            if not user_metadata:
+                # if user didn't provide metadata, we default to llc
+                cs = get_extra_metadata(domain='cs', nx=self.nx)
+                extra_metadata = cs
         # --------------- /LEGACY ----------------------
 
         self.layers = _guess_layers(data_dir)
@@ -477,11 +493,11 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
         # seems sloppy to hard code this here
         # TODO: move this metadata to variables.py
         if has_faces:
-            self._dimensions.append(LLC_FACE_DIMNAME)
+            self._dimensions.append(FACE_DIMNAME)
             data = np.arange(self.nface)
             attrs = {'standard_name': 'face_index'}
-            dims = [LLC_FACE_DIMNAME]
-            self._variables[LLC_FACE_DIMNAME] = xr.Variable(dims, data, attrs)
+            dims = [FACE_DIMNAME]
+            self._variables[FACE_DIMNAME] = xr.Variable(dims, data, attrs)
 
         # do the same for layers
         for layer_name, n_layer in self.layers.items():
@@ -612,10 +628,13 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
             ddir = self.data_dir
 
         basename = os.path.join(ddir, fname_base)
+        chunks = "CS" if self.cs else "3D"
+
         try:
             vardata = read_mds(basename, iternum, endian=self.endian,
                                llc=self.llc, llc_method=self.llc_method,
-                               extra_metadata=extra_metadata)
+                               extra_metadata=extra_metadata, chunks=chunks)
+
         except IOError as ioe:
             # that might have failed because there was no meta file present
             # we can try to get around this by specifying the shape and dtype
@@ -627,15 +646,16 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
                 data_shape = self.default_shape_3D
             elif ndims == 2 or self.nz == 1:
                 data_shape = self.default_shape_2D
+            elif self.cs:
+                data_shape = None  # handle this inside read_mds
             else:
                 raise ValueError("Can't determine shape "
                                  "of variable %s" % prefix)
-
             vardata = read_mds(basename, iternum, endian=self.endian,
                                dtype=self.default_dtype,
                                shape=data_shape, llc=self.llc,
                                llc_method=self.llc_method,
-                               extra_metadata=extra_metadata)
+                               extra_metadata=extra_metadata, chunks=chunks)
 
         for vname, data in vardata.items():
             # we now have to revert to the original prefix once the file is read
@@ -679,7 +699,7 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
             # or add an extra axis to the data. Let's try the former, on the
             # grounds that it is simpler for the user.
             if ((len(dims) == 3 and data.ndim == 2) or
-                (self.llc and (len(dims) == 3 and data.ndim == 3))):
+                    ((self.llc or self.cs) and (len(dims) == 3 and data.ndim == 3))):
                 # Deleting the first dimension (z) assumes that 2D data always
                 # corresponds to x,y horizontal data. Is this really true?
                 # The answer appears to be yes: 2D (x|y,z) data retains the
@@ -695,6 +715,8 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
 
             if self.llc:
                 dims, data = _reshape_for_llc(dims, data)
+            if self.cs:
+                dims, data = _reshape_for_cs(dims, data)
 
             # need to add an extra dimension at the beginning if we have a time
             # variable
@@ -717,7 +739,7 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
 
     def close(self):
         for var in list(self._variables):
-            del self._variables['var']
+            del self._variables[var]
 
 
 def _guess_model_nz(data_dir):
@@ -732,7 +754,7 @@ def _guess_model_nz(data_dir):
     return nz
 
 
-def _guess_model_horiz_dims(data_dir, is_llc=False):
+def _guess_model_horiz_dims(data_dir, is_llc=False, is_cs=False):
     try:
         xc_meta = parse_meta_file(os.path.join(data_dir, 'XC.meta'))
         nx = int(xc_meta['dimList'][0][0])
@@ -742,6 +764,12 @@ def _guess_model_horiz_dims(data_dir, is_llc=False):
     if is_llc:
         nface = LLC_NUM_FACES
         ny //= nface
+    elif is_cs:
+        nface = CS_NUM_FACES
+        if ny > nx:
+            ny //= nface
+        else:
+            nx //= nface
     else:
         nface = None
     return nface, ny, nx
@@ -767,6 +795,7 @@ def _get_all_grid_variables(geometry, grid_dir=None, layers={}):
     """"Put all the relevant grid metadata into one big dictionary."""
     possible_hcoords = {'cartesian': horizontal_coordinates_cartesian,
                         'llc': horizontal_coordinates_llc,
+                        'cs': horizontal_coordinates_cs,
                         'curvilinear': horizontal_coordinates_curvcart,
                         'sphericalpolar': horizontal_coordinates_spherical}
     hcoords = possible_hcoords[geometry]
@@ -960,6 +989,23 @@ def _reshape_for_llc(dims, data):
         if dim in dims:
             # add face dimension to dims
             jdim = dims.index(dim)
-            dims.insert(jdim, LLC_FACE_DIMNAME)
+            dims.insert(jdim, FACE_DIMNAME)
     assert data.ndim==len(dims), '%r %r' % (data.shape, dims)
     return dims, data
+
+def _reshape_for_cs(dims, data):
+    """Take dims and data and return modified / reshaped dims and data for
+    cs geometry."""
+
+    # the data should already come shaped correctly for cs
+    # but the dims are not yet correct
+
+    # the only dimensions that get expanded into faces
+    expand_dims = ['j', 'j_g']
+    for dim in expand_dims:
+        if dim in dims:
+            # add face dimension to dims
+            jdim = dims.index(dim)
+            dims.insert(jdim+1, FACE_DIMNAME)
+    assert data.ndim == len(dims), '%r %r' % (data.shape, dims)
+    return dims, data
