@@ -47,7 +47,10 @@ def test_open_mdsdataset_minimal(all_mds_datadirs):
         nz, ny, nx = eshape
         nface = None
     elif len(eshape) == 4:
-        nz, nface, ny, nx = eshape
+        if expected['geometry'] == 'cs':
+            nz, ny, nface, nx = eshape
+        else:
+            nz, nface, ny, nx = eshape
     else:
         raise ValueError("Invalid expected shape")
     coords = {'i': np.arange(nx),
@@ -143,10 +146,17 @@ def test_open_dataset_no_meta(all_mds_datadirs):
     ny, nx = shape[-2:]
     shape_2d = shape[1:]
     dims_2d = ('j', 'i')
-    if expected['geometry']=='llc':
+    if expected['geometry'] == 'llc':
         dims_2d = ('face',) + dims_2d
         ny = nx*shape[-3]
-    dims_3d = dims_2d if nz==1 else ('k',) + dims_2d
+    elif expected['geometry'] == 'cs':
+        dims_2d = ('j', 'face', 'i')
+        if len(shape) == 4:
+            nz, ny, nface, nx = shape
+        elif len(shape) == 3:
+            ny, nface, nx = shape
+
+    dims_3d = dims_2d if nz == 1 else ('k',) + dims_2d
     dims_2d = ('time',) + dims_2d
     dims_3d = ('time',) + dims_3d
 
@@ -158,6 +168,8 @@ def test_open_dataset_no_meta(all_mds_datadirs):
     to_hide = ['T.%010d.meta' % it, 'Eta.%010d.meta' % it]
     with hide_file(dirname, *to_hide):
         ds = xmitgcm.open_mdsdataset(dirname, prefix=['T', 'Eta'], **kwargs)
+        print(ds['T'].dims)
+        print(dims_3d)
         assert ds['T'].dims == dims_3d
         assert ds['T'].values.ndim == len(dims_3d)
         assert ds['Eta'].dims == dims_2d
@@ -241,7 +253,7 @@ def test_swap_dims(all_mds_datadirs):
     # make sure we never swap if not reading grid
     assert 'i' in xmitgcm.open_mdsdataset(dirname,
         iters=None, read_grid=False, geometry=expected['geometry'])
-    if expected['geometry'] in ('llc', 'curvilinear'):
+    if expected['geometry'] in ('llc', 'cs', 'curvilinear'):
         # make sure swapping is not the default
         ds = xmitgcm.open_mdsdataset(dirname, **kwargs)
         assert 'i' in ds
@@ -583,4 +595,4 @@ def test_levels_diagnostics(mds_datadirs_with_inputfiles):
 
         with pytest.warns(UserWarning, match='nz will be ignored'):
             xmitgcm.open_mdsdataset(dirname, prefix=[diagname], levels=levels, 
-                                    geometry=expected['geometry'], nz=12)
\ No newline at end of file
+                                    geometry=expected['geometry'], nz=12)
