@@ -133,6 +133,22 @@ _experiments = {
                               (0, np.datetime64('2013-11-12T12:00:00.000000000')),
                               (1, np.datetime64('2013-11-12T12:02:00.000000000'))],
                           'prefixes': ['THETA']},
+
+    'global_oce_cs32': {'geometry': 'cs',
+                        'dlink': dlroot + '14066390',
+                        'md5': '209193f4a183307b89337bb18e2e9451',
+                        'shape': (15, 32, 6, 32), 'test_iternum': 72020,
+                        'dtype': np.dtype('f4'),
+                        'expected_values': {'XC': ((2, 3, 5), -29.98921)},
+                        'diagnostics': ('oceDiag', ['DRHODR',
+                                                    'RHOAnoma',
+                                                    'CONVADJ',
+                                                    'GM_Kwx',
+                                                    'GM_Kwy',
+                                                    'GM_Kwz',
+                                                    'GM_PsiX',
+                                                    'GM_PsiY'])},
+
     'ideal_2D_oce': {'geometry': 'sphericalpolar',
                      'dlink': dlroot + '17288255',
                      'md5': 'd8868731ff6a8fd951babefbc5ea69ba',
@@ -167,13 +183,13 @@ _grids = {
                      'dlink': dlroot + '14072591',
                      'md5': '92b28c65e0dfb54b253bfcd0a249359b',
                      'gridfile': 'tile<NFACET>.mitgrid',
-                     'nx': 270, 'shape': (6, 270, 270)}  # ,
+                     'nx': 270, 'shape': (6, 270, 270)},
 
-    #    'grid_cs32': {'geometry': 'cs', 'domain': 'cs',
-    #                  'dlink': dlroot + '14072597',
-    #                  'md5': '848cd5b6daab5b069e96a0cff67d4b57',
-    #                  'gridfile': 'grid_cs32.face<NFACET>.bin',
-    #                  'nx': 32, 'shape': (6, 32, 32)}
+    'grid_cs32': {'geometry': 'cs', 'domain': 'cs',
+                  'dlink': dlroot + '14072597',
+                  'md5': '848cd5b6daab5b069e96a0cff67d4b57',
+                  'gridfile': 'grid_cs32.face<NFACET>.bin',
+                  'nx': 32, 'shape': (6, 32, 32)}
 }
 
 
@@ -290,6 +306,11 @@ def llc_mds_datadirs(tmpdir_factory, request):
     return setup_mds_dir(tmpdir_factory, request, _experiments)
 
 
+@pytest.fixture(scope='module', params=['global_oce_cs32'])
+def cs_mds_datadirs(tmpdir_factory, request):
+    return setup_mds_dir(tmpdir_factory, request, _experiments)
+
+
 @pytest.fixture(scope='module', params=_grids.keys())
 def all_grid_datadirs(tmpdir_factory, request):
     return setup_mds_dir(tmpdir_factory, request, _grids)
